from setuptools import setup, find_packages

setup(
    name='xiaowupkg',
    version='1.0.3',
    author='wzh',
    author_email='wzh@example.com',
    description="it's wzh's packages include many useful menthod",
    packages=['xiaowupkg'],
    install_requires=[
        'requests>=2.0.0',
        'pandas>=1.3.0',
    ],
)
